@@ -1,6 +1,5 @@
 import argparse
-import sys 
-from src.m_shape.detectFacialFeatures import process_mshape
+from .detectFacialFeatures import process_mshape
 import cv2
 import numpy as np
 
@@ -22,17 +21,17 @@ def predict_m_shape(front_face_img):
   front_face_img = front_face_img[:, :, ::-1].copy() 
 
   cv2.imwrite("front_face_img.jpg", front_face_img)
-  return process_mshape("front_face_img.jpg", True, SRC_DIR / 'utilities/shape_predictor_81_face_landmarks.dat')
+  return process_mshape("front_face_img.jpg", True, str(SRC_DIR / 'm_shape/utilities/shape_predictor_81_face_landmarks.dat'))
 
 if __name__ == "__main__":
   parser = argparse.ArgumentParser(description='MSHAPE and RECEDING HAIRLINE project')
   parser.add_argument('--single', type=str, default=False)
   # parser.add_argument('--single', type=str, default=r'C:\Users\Public\ferdy\front_face\black\male_black_hair\male_black_hair10.jpg', type=str)
   # TODO
-  parser.add_argument('--input', default=r'/Users/ferdy/Documents/HairCoSys/m_shape_standalone/sample_images/male_black_hair0.jpg', type=str)
+  parser.add_argument('--input', default=str(SRC_DIR / 'sample_images/male_black_hair0.jpg'), type=str)
   parser.add_argument('--m_shape', default=True, type=str)
   parser.add_argument('--verbose', default=False, type=str)
   # TODO
-  parser.add_argument('--config_dat_path', default=r'/Users/ferdy/Documents/HairCoSys/m_shape_standalone/utilities/shape_predictor_81_face_landmarks.dat', type=str)
+  parser.add_argument('--config_dat_path', default=str(SRC_DIR / 'm_shape/utilities/shape_predictor_81_face_landmarks.dat'), type=str)
   args=parser.parse_args()
   main(args)
