@@ -3,8 +3,7 @@ from imutils import face_utils
 import dlib
 import cv2
 import numpy as np
-from utils.print_utils import show, write_on_image 
-
+from .print_utils import show, write_on_image 
 
 def draw_calc_brows(clone, shape, name, lst, iterList):
   step = 0.05 * clone.shape[0]
